@@ -25,7 +25,7 @@ class NoContextQA:
         self.NTC = Normalize.NormalizeTextClass()
         self.OBQA = OpenBookQA.OpenBookQA()
         self.SUM = Summarize.Summarize()
-        self.debug = True
+        self.debug = False
 
     # atleast one of these
     def setQuestion(self, question):
