@@ -3,7 +3,7 @@ from transformers import pipeline
 class Summarize:
 
     def __init__(self):
-        self.MODELNAME = constants.SUMMARYMODELNAME
+        self.MODELNAME = "facebook/bart-large-cnn"
         self.summarizer = pipeline("summarization", model=self.MODELNAME)
 
     def setText(self, text):
